from .button import Button

from dataclasses_json import dataclass_json
from dataclasses import dataclass
from typing import Optional, List


@dataclass_json
@dataclass
class Component:
    
    type: str
    """
    Required.

    Describes the component type.

    Supported Options:
        • header
        • body
        • button
    
    For text-based templates, we only support the type=body.
    """

    sub_type: Optional[str] = None
    """
    Required when type=button. Not used for the other types.

    Type of button to create.

    Supported Options:
        • quick_reply: 
            Refers to a previously created quick reply button that 
            allows for the customer to return a predefined message.

        • url: 
            Refers to a previously created button that allows the customer 
            to visit the URL generated by appending the text parameter to 
            the predefined prefix URL in the template.
    """

    parameters: Optional[List[Button]] = None
    """
    Required when type=button.

    Array of parameter objects with the content of the message.

    For components of type=button, see the button parameter object.
    """

    index: Optional[str] = None
    """    	
    Required when type=button.

    Not used for the other types.
    Position index of the button.
    
    You can have up to 3 buttons using index values of 0 to 2.
    """